Builtin tools - Faber 1.0 documentation

###  |

# Builtin tools

The following tools are provided by Faber.

`cc`

Defined in: | faber.tools.cc
Actions: | makedep, compile, archive, link

  Generic C compiler base class.

`cxx`

Defined in: | faber.tools.cxx
Actions: | makedep, compile, archive, link

  Generic C++ compiler base class.

`gcc`

Defined in: | faber.tools.gcc
Inheritance: |
Actions: | makedep, compile, archive, link

  GCC C compiler.

`gxx`

Defined in: | faber.tools.gxx
Inheritance: |
Actions: | makedep, compile, archive, link

  GCC C++ compiler.

`clang`

Defined in: | faber.tools.clang
Inheritance: |
Actions: | makedep, compile, archive, link

  CLang C compiler.

`clangxx`

Defined in: | faber.tools.clangxx
Inheritance: |
Actions: | makedep, compile, archive, link

  CLang C++ compiler.

`msvc`

Defined in: | faber.tools.msvc
Inheritance: |
Actions: | makedep, compile, archive, link

  MSVC C & C++ compiler.

`python`

Defined in: | faber.tools.python
Actions: | run

  A (C)Python interpreter.